@@ -39,7 +39,7 @@
 #' for a specific AE.
 #' @param cores the number of cores to use for parallel execution.
 #' @references Li, S. and Zhao, L. (2020). Adverse event enrichment tests using 
-#' VAERS. \href{https://arxiv.org/abs/2007.02266}{arXiv:2007.02266}.
+#' VAERS. \doi{10.48550/arXiv.2007.02266}.
 #' 
 #' Subramanian, A.e.a. (2005). Gene set enrichment analysis: a knowledge-based
 #' approach for interpreting genome-wide expression profiles. Proc Natl Acad
@@ -53,7 +53,7 @@
 #' @return A list containing 2 data.frames named **Final_result** and **AE_info**.
 #' 
 #' The **Final_result** data.frame contains the following columns: 
-#' \itemize{
+#' \describe{
 #'   \item{GROUP_NAME: }{AE group names}
 #'   \item{ES: }{enrichment score}
 #'   \item{p_value: }{p value of the enrichment test}
@@ -61,7 +61,7 @@
 #' }
 #' 
 #' The **AE_info** contains the following columns:
-#' \itemize{
+#' \describe{
 #'   \item{AE_NAME: }{AE names}
 #'   \item{OR: }{odds ratio for each individual AE}
 #'   \item{p_value: }{p value for AE-drug association}
@@ -124,15 +124,14 @@ enrich = function(data, dd.group, drug.case, drug.control = NULL,
   }
 }
 
-#' @description Perform Adverse Event Enrichment Tests
-#' The enrich function is used to perform Adverse event (AE) enrichment analysis.
-#' Unlike the continuous gene expression data, AE data are counts. Therefore,
-#' AE data has many zeros and ties. We propose two enrichment tests. AEFisher is
-#' a modified Fisher's exact test based on pre-selected significant AEs, while
-#' AEKS is based on a modified Kolmogorov-Smirnov statistic.
-#' 
-#' Use the function `enrich` to fit models and inspect results.
-#' 
-#' See our \href{https://github.com/umich-biostatistics/AEenrich}{Github home page} 
-#' or run ?enrich for examples.
+#' @description
+#' Perform adverse event enrichment tests. The \code{enrich} function implements
+#' enrichment analysis for adverse event count data, which contain many zeros and
+#' ties. Two methods are provided: \code{AEFisher}, a modified Fisher’s exact test
+#' based on pre-selected significant adverse events, and \code{AEKS}, a modified
+#' Kolmogorov–Smirnov statistic. See the GitHub home page at
+#' \url{https://github.com/umich-biostatistics/AEenrich} or run \code{?enrich} for
+#' examples.
 "_PACKAGE"
+
+utils::globalVariables(c(".", "i"))
